@@ -1,8 +1,6 @@
 from tests import TestCase
-from src.masonite.foundation import Application
-import os
 from src.masonite.response import Response
-from src.masonite.routes import Router, Route
+from src.masonite.routes import Route
 
 
 class TestResponseRedirect(TestCase):
@@ -16,12 +14,23 @@ class TestResponseRedirect(TestCase):
         self.assertEqual(self.response.get_status(), 302)
         self.assertEqual(self.response.header_bag.get("Location").value, "/")
 
+        self.response.redirect("/", query_params={"key": "value"})
+        self.assertEqual(self.response.header_bag.get("Location").value, "/?key=value")
+
     def test_redirect_to_route_named_route(self):
         self.response.redirect(name="home-redirect")
         self.assertEqual(self.response.get_status(), 302)
         self.assertEqual(self.response.header_bag.get("Location").value, "/")
 
+        self.response.redirect(name="home-redirect", query_params={"key": "value"})
+        self.assertEqual(self.response.header_bag.get("Location").value, "/?key=value")
+
     def test_redirect_to_url(self):
         self.response.redirect(url="/login")
         self.assertEqual(self.response.get_status(), 302)
         self.assertEqual(self.response.header_bag.get("Location").value, "/login")
+
+        self.response.redirect(url="/login", query_params={"key": "value"})
+        self.assertEqual(
+            self.response.header_bag.get("Location").value, "/login?key=value"
+        )
