@@ -1,5 +1,6 @@
 from src.masonite.providers import Provider
 from src.masonite.facades import Gate
+from ..tasks.TaskTest import TaskTest
 
 
 class AppProvider(Provider):
@@ -11,5 +12,7 @@ class AppProvider(Provider):
         Gate.define("view-posts", lambda user=None: True)
         Gate.define("display-admin", lambda user: user.email == "admin@gmail.com")
 
+        self.application.make("scheduler").add(TaskTest().daily())
+
     def boot(self):
         pass
